@@ -507,6 +507,12 @@ sub gd {
   my $gd  = $existing_gd || $pkg->new($width,$height,
 				      ($self->{truecolor} && $pkg->can('isTrueColor') ? 1 : ())
 				     );
+
+  if ($self->{truecolor} 
+      && $pkg->can('saveAlpha')) {
+      $gd->saveAlpha(1);
+  }
+
   my %translation_table;
   for my $name (keys %COLORS) {
     my $idx = $gd->colorAllocate(@{$COLORS{$name}});
@@ -515,11 +521,15 @@ sub gd {
 
   $self->{translations} = \%translation_table;
   $self->{gd}           = $gd;
+
+  
+  eval {$gd->alphaBlending(0)};
   if ($self->bgcolor) {
     $gd->fill(0,0,$self->bgcolor);
   } elsif (eval {$gd->isTrueColor}) {
     $gd->fill(0,0,$translation_table{'white'});
   }
+  eval {$gd->alphaBlending(1)};
 
   my $pl = $self->pad_left;
   my $pt = $self->pad_top;
@@ -1032,7 +1042,7 @@ sub colorClosest {
 sub bgcolor {
    my $self = shift;
    return unless $self->{bgcolor};
-   $self->translate_color($self->{bgcolor});
+   return $self->translate_color($self->{bgcolor});
 }
 
 sub set_pen {
@@ -2254,9 +2264,12 @@ glyphs collide.  By default, they will simply overlap (value 0).  A
 until there is room for them.  A -bump value of -1 will cause
 overlapping glyphs to bump upwards.  You may also provide a -bump
 value of +2 or -2 to activate a very simple type of collision control
-in which each feature occupies its own line.  This is useful for
+in which each feature occupies its own line. This is useful for
 showing dense, nearly-full length features such as similarity hits.
-The bump argument can also be a code reference; see below.
+Finally, a bump of 3 or the string "fast" will turn on a faster
+collision-detection algorithm that works well when all features have
+identical height.  The bump argument can also be a code reference; see
+below.
 
 If you would like to see more horizontal whitespace between features
 that occupy the same line, you can specify it with the B<-hbumppad>
